==> gsequencer-0.7.107.tar.gz: gsequencer-0.7.107/ags/audio/task/ags_set_samplerate.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2015 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_SET_SAMPLERATE_H__
#define __AGS_SET_SAMPLERATE_H__

#include <glib.h>
#include <glib-object.h>

#include <ags/thread/ags_task.h>

#define AGS_TYPE_SET_SAMPLERATE                (ags_set_samplerate_get_type())
#define AGS_SET_SAMPLERATE(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerate))
#define AGS_SET_SAMPLERATE_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST((class), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerateClass))
#define AGS_IS_SET_SAMPLERATE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE((obj), AGS_TYPE_SET_SAMPLERATE))
#define AGS_IS_SET_SAMPLERATE_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE((class), AGS_TYPE_SET_SAMPLERATE))
#define AGS_SET_SAMPLERATE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS((obj), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerateClass))

typedef struct _AgsSetSamplerate AgsSetSamplerate;
typedef struct _AgsSetSamplerateClass AgsSetSamplerateClass;

struct _AgsSetSamplerate
{
  AgsTask task;

  GObject *gobject;
  guint samplerate;
};

struct _AgsSetSamplerateClass
{
  AgsTaskClass task;
};

GType ags_set_samplerate_get_type();

AgsSetSamplerate* ags_set_samplerate_new(GObject *gobject,
					 guint samplerate);

#endif /*__AGS_SET_SAMPLERATE_H__*/

==> gsequencer-0.8.5.tar.gz: gsequencer-0.8.5/ags/audio/task/ags_set_samplerate.h <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2015 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __AGS_SET_SAMPLERATE_H__
#define __AGS_SET_SAMPLERATE_H__

#include <glib.h>
#include <glib-object.h>

#include <ags/thread/ags_task.h>

#define AGS_TYPE_SET_SAMPLERATE                (ags_set_samplerate_get_type())
#define AGS_SET_SAMPLERATE(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerate))
#define AGS_SET_SAMPLERATE_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST((class), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerateClass))
#define AGS_IS_SET_SAMPLERATE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE((obj), AGS_TYPE_SET_SAMPLERATE))
#define AGS_IS_SET_SAMPLERATE_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE((class), AGS_TYPE_SET_SAMPLERATE))
#define AGS_SET_SAMPLERATE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS((obj), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerateClass))

typedef struct _AgsSetSamplerate AgsSetSamplerate;
typedef struct _AgsSetSamplerateClass AgsSetSamplerateClass;

struct _AgsSetSamplerate
{
  AgsTask task;

  GObject *scope;
  guint samplerate;
};

struct _AgsSetSamplerateClass
{
  AgsTaskClass task;
};

GType ags_set_samplerate_get_type();

AgsSetSamplerate* ags_set_samplerate_new(GObject *scope,
					 guint samplerate);

#endif /*__AGS_SET_SAMPLERATE_H__*/
